@@ -1,6 +1,9 @@
 from flask import Flask
+from skywalking.plugins import sw_requests
+
 from skywalking_flask import SkywalkingFlask
 
+sw_requests.install()
 
 app = Flask(__name__)
 
